==> gp2c_0.0.9pl2.orig.tar.gz: gp2c-0.0.9pl2/src/patchfunc.h <==
/*
Copyright (C) 2000-2013  The PARI group.

This file is part of the GP2C package.

PARI/GP is free software; you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the Free Software
Foundation. It is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY WHATSOEVER.

Check the License for details. You should have received a copy of it, along
with the package; see the file 'COPYING'. If not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.*/

/*Patch for list of gp functions. Must be include after header.h.*/
typedef enum {GPuser_private,
              GPgpmany,
              GPinstall,GPaddhelp,
              GPgrandO,
              GPbreak,GPnext,GPreturn,
              GPfor,GPforstep,GPforstepvec,GPforprime,GPforvec,GPfordiv,
              GPdoloop,
              GPlabel,
              GPglobal,GPlocal,
              GPif,
              GPprod,GPsum,GPsumdiv,GPprodeuler,
              GPuntil,GPwhile,GPwhilenull,
              GPmakevec,GPmakemat,
              GPvector,GPvectorsmall,GPvectorv,GPmatrix,
              GPiferr,
              GPinitfunc,GPcopyarg,
              GPclosure
} GPspec_private;

struct patchfunc_s
{
  const char *gpname;
  const char *code;
  int type;
  int mode;
  int spec;
} patchfunc[]={
/*Override previous definition in pari/src/init.c*/
{"O",NULL,Ggen,0,GPgrandO},
{"addhelp",NULL,Gnotype,(1<<Msemicolon),GPaddhelp},
{"break",NULL,Gvoid,0,GPbreak},
{"next",NULL,Gvoid,0,GPnext},
{"for","GGIG",Gnotype,(1<<Msemicolon),GPfor},
{"fordiv",NULL,Gnotype,(1<<Msemicolon),GPfordiv},
{"forstep","GIGGGG",Gnotype,(1<<Msemicolon),GPforstep},
{"global",NULL,Gnotype,(1<<Msemicolon),GPglobal},
{"if","GII",Gnotype,(1<<Msemicolon),GPif},
{"iferr","IEII",Gnotype,(1<<Msemicolon),GPiferr},
{"install",NULL,Gnotype,(1<<Msemicolon),GPinstall},
{"local",NULL,Gnotype,(1<<Msemicolon),GPlocal},
{"my",NULL,Gnotype,(1<<Msemicolon),GPlocal},
{"prod","NULL",Gnotype,(1<<Msemicolon),GPprod},
{"prodeuler",NULL,Gnotype,(1<<Msemicolon),GPprodeuler},
{"return",NULL,Gnotype,(1<<Mterm),GPreturn},
{"sum",NULL,Gnotype,(1<<Msemicolon),GPsum},
{"sumdiv",NULL,Gnotype,(1<<Msemicolon),GPsumdiv},
{"until","EI",Gnotype,(1<<Msemicolon),GPuntil},
{"vector",NULL,Gnotype,(1<<Msemicolon),GPvector},
{"vectorsmall",NULL,Gnotype,(1<<Msemicolon),GPvectorsmall},
{"vectorv",NULL,Gnotype,(1<<Msemicolon),GPvectorv},
{"matrix",NULL,Gnotype,(1<<Msemicolon),GPmatrix},
{"while","EI",Gnotype,(1<<Msemicolon),GPwhile},
/* New definition*/
{"_closure",NULL,Gnotype,0,GPclosure},
{"_copyarg","",Gvoid,(1<<Msemicolon),GPcopyarg},
{"_doloop","I",Gnotype,(1<<Msemicolon),GPdoloop},
{"_forstepvec","GIGGGGGG",Gnotype,(1<<Msemicolon),GPforstepvec},
{"_gerepilemany",NULL,Gvoid,(1<<Msemicolon),GPgpmany},
{"_initfunc","",Gvoid,(1<<Msemicolon),GPinitfunc},
{"_label",NULL,Gvoid,0,GPlabel},
{"_makevec","*",Gnotype,(1<<Msemicolon),GPmakevec},
{"_whilenull","EI",Gnotype,(1<<Msemicolon),GPwhilenull},
{NULL,NULL,0,0,0}};

==> gp2c_0.0.11pl2.orig.tar.gz: gp2c-0.0.11pl2/src/patchfunc.h <==
/*
Copyright (C) 2000-2013  The PARI group.

This file is part of the GP2C package.

PARI/GP is free software; you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the Free Software
Foundation. It is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY WHATSOEVER.

Check the License for details. You should have received a copy of it, along
with the package; see the file 'COPYING'. If not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.*/

/*Patch for list of gp functions. Must be include after header.h.*/
typedef enum {GPuser_private,
              GPgpmany,
              GPinstall,GPaddhelp,
              GPgrandO,
              GPbreak,GPnext,GPreturn,
              GPfor,GPforstep,GPforstepvec,GPforprime,GPforvec,
              GPfordiv,GPfordivfactored,
              GPdoloop,
              GPlabel,
              GPglobal,GPlocal,GPlocalbitprec,GPlocalprec,
              GPif,
              GPprod,GPsum,GPsumdiv,GPprodeuler,
              GPuntil,GPwhile,GPwhilenull,
              GPmakevec,GPmakemat,GPmakevecsmall,
              GPvector,GPvectorsmall,GPvectorv,GPmatrix,
              GPiferr,
              GPinitfunc,GPcopyarg,
              GPclosure, GPself
} GPspec_private;

struct patchfunc_s
{
  const char *gpname;
  const char *code;
  int type;
  int mode;
  int spec;
} patchfunc[]={
/*Override previous definition in pari/src/init.c*/
{"O",NULL,Ggen,0,GPgrandO},
{"addhelp",NULL,Gnotype,(1<<Msemicolon),GPaddhelp},
{"break",NULL,Gvoid,0,GPbreak},
{"next",NULL,Gvoid,0,GPnext},
{"for","GGIG",Gnotype,(1<<Msemicolon),GPfor},
{"fordiv",NULL,Gnotype,(1<<Msemicolon),GPfordiv},
{"fordivfactored",NULL,Gnotype,(1<<Msemicolon),GPfordivfactored},
{"forstep","GIGGGG",Gnotype,(1<<Msemicolon),GPforstep},
{"global",NULL,Gnotype,(1<<Msemicolon),GPglobal},
{"if","GII",Gnotype,(1<<Msemicolon),GPif},
{"iferr","IEII",Gnotype,(1<<Msemicolon),GPiferr},
{"install",NULL,Gnotype,(1<<Msemicolon),GPinstall},
{"local",NULL,Gnotype,(1<<Msemicolon),GPlocal},
{"localbitprec","G",Gvoid,0,GPlocalbitprec},
{"localprec","G",Gvoid,0,GPlocalprec},
{"my",NULL,Gnotype,(1<<Msemicolon),GPlocal},
{"prod",NULL,Gnotype,(1<<Msemicolon),GPprod},
{"prodeuler",NULL,Gnotype,(1<<Msemicolon),GPprodeuler},
{"return",NULL,Gnotype,(1<<Mterm),GPreturn},
{"self","",Gclosure,0,GPself},
{"sum",NULL,Gnotype,(1<<Msemicolon),GPsum},
{"sumdiv",NULL,Gnotype,(1<<Msemicolon),GPsumdiv},
{"until","EI",Gnotype,(1<<Msemicolon),GPuntil},
{"vector",NULL,Gnotype,(1<<Msemicolon),GPvector},
{"vectorsmall",NULL,Gnotype,(1<<Msemicolon),GPvectorsmall},
{"vectorv",NULL,Gnotype,(1<<Msemicolon),GPvectorv},
{"matrix",NULL,Gnotype,(1<<Msemicolon),GPmatrix},
{"while","EI",Gnotype,(1<<Msemicolon),GPwhile},
/* New definition*/
{"_closure",NULL,Gnotype,0,GPclosure},
{"_copyarg","",Gvoid,(1<<Msemicolon),GPcopyarg},
{"_doloop","I",Gnotype,(1<<Msemicolon),GPdoloop},
{"_forstepvec","GIGGGGGG",Gnotype,(1<<Msemicolon),GPforstepvec},
{"_gerepilemany",NULL,Gvoid,(1<<Msemicolon),GPgpmany},
{"_initfunc","",Gvoid,(1<<Msemicolon),GPinitfunc},
{"_label",NULL,Gvoid,0,GPlabel},
{"_makevec","*",Gnotype,(1<<Msemicolon),GPmakevec},
{"_makevecsmall","*",Gnotype,(1<<Msemicolon),GPmakevecsmall},
{"_whilenull","EI",Gnotype,(1<<Msemicolon),GPwhilenull},
{NULL,NULL,0,0,0}};
